==> auto_route-8.0.2.tar.gz: example/lib/mobile/screens/profile/my_books_page.dart <==
import 'package:auto_route/auto_route.dart';
import 'package:example/mobile/router/router.gr.dart';
import 'package:flutter/material.dart';

//ignore_for_file: public_member_api_docs
@RoutePage<String>()
class MyBooksPage extends StatelessWidget {
  final String? filter;

  MyBooksPage({Key? key, @queryParam this.filter = 'none'}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Text(
              'My Books -> filter: $filter',
              style: Theme.of(context).textTheme.titleLarge,
            ),
            const SizedBox(height: 16),
            Text(
              'Fragment Support? ${context.routeData.fragment}',
              style: Theme.of(context).textTheme.bodyLarge,
            ),
            const SizedBox(height: 32),
            ElevatedButton(
              onPressed: () {
                context.navigateTo(
                  SettingsTab(tab: 'newSegment', query: 'newQuery'),
                );
              },
              child: Text('navigate to /settings/newSegment'),
            ),
            ElevatedButton(
              onPressed: () => context.back(),
              child: Text('Navigate back'),
            ),
            ElevatedButton(
              onPressed: () => context.router.root.pushAndPopUntil(HomeRoute(), predicate: (_) => false),
              child: Text('Pop until /home'),
            ),
          ],
        ),
      ),
    );
  }
}

==> auto_route-8.1.0.tar.gz: example/lib/mobile/screens/profile/my_books_page.dart <==
import 'package:auto_route/auto_route.dart';
import 'package:example/mobile/router/router.gr.dart';
import 'package:flutter/material.dart';

//ignore_for_file: public_member_api_docs
@RoutePage<String>()
class MyBooksPage extends StatelessWidget {
  final String? filter;

  MyBooksPage({Key? key, @queryParam this.filter = 'none'}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Text(
              'My Books -> filter: $filter',
              style: Theme.of(context).textTheme.titleLarge,
            ),
            const SizedBox(height: 16),
            Text(
              'Fragment Support? ${context.routeData.fragment}',
              style: Theme.of(context).textTheme.bodyLarge,
            ),
            const SizedBox(height: 32),
            ElevatedButton(
              onPressed: () {
                context.navigateTo(
                  SettingsTab(tab: 'newSegment', query: 'newQuery'),
                );
              },
              child: Text('navigate to /settings/newSegment'),
            ),
            ElevatedButton(
              onPressed: () => context.back(),
              child: Text('Navigate back'),
            ),
            ElevatedButton(
              onPressed: () => context.router.root
                  .pushAndPopUntil(HomeRoute(), predicate: (_) => false),
              child: Text('Pop until /home'),
            ),
          ],
        ),
      ),
    );
  }
}
